@@ -36,7 +36,7 @@ __PACKAGE__->validates(status => (
 sub set_from_request($self, $request) {
   $self->set_columns_recursively($request->nested_params)
       ->insert_or_update;
-  return $self;
+  return $self->valid;
 }
 
 sub status_options($self) {
