@@ -27,15 +27,16 @@ __PACKAGE__->belongs_to(
 );
 
 __PACKAGE__->accept_nested_for('role', +{find_with_uniques=>1});
-__PACKAGE__->validates(role => presence=>1, result=>1, with=>'unique_role');
+__PACKAGE__->validates(role => presence=>1, with=>'unique_role');
 
 sub unique_role {
   my ($self, $attribute_name, $record, $opts) = @_;
 
+  return if $self->in_storage && !$self->is_changed;
   return unless my $result = $self->result_source->resultset
   ->search({person_id=>$self->person_id,'role.label'=>$record->label},{join=>'role'})
   ->single;
-  
+
   $self->errors->add($attribute_name, \'already has role {{role_label}}', +{%$opts, role_label=>$record->label});
 }
 
